<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX очистка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Папки для очистки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Delete Logs</source>
        <translation>Удаление журналов</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Old logs</source>
        <translation>Старые журналы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>All logs</source>
        <translation>Все журналы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="411"/>
        <location filename="../mainwindow.ui" line="604"/>
        <source>Don&apos;t empty</source>
        <translation>Не очищать</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Очистить корзину</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Selected user</source>
        <translation>Выбранный пользователь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>All users</source>
        <translation>Все пользователи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.ui" line="630"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Clear APT Cache</source>
        <translation>Очистить кэш APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Old files</source>
        <translation>Старые файлы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Free Disk Space for User</source>
        <translation>Свободное дисковое пространство для пользователя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Select user to repair</source>
        <translation>Выберите пользователя для восстановления</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Select user:</source>
        <translation>Выбор пользователя:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Графическая утилита для анализа использования дисков</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Запустить анализатор использования дисков</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Schedule</source>
        <translation>Расписание</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>No automatic clean</source>
        <translation>Без автоматической очистки</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Daily</source>
        <translation>Ежедневно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Weekly</source>
        <translation>Каждую неделю</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Monthly</source>
        <translation>Ежемесячно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Cleanup command done</source>
        <translation>Команда очистки завершена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>%1 MiB were freed</source>
        <translation>%1 МБ было освобождено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>About</source>
        <translation>О приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Quick and safe removal of old files</source>
        <translation>Быстрое и безопасное удаление старых файлов</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Вы должны запустить программу от имени суперпользователя.</translation>
    </message>
</context>
</TS>
